paidiverpy.models.custom_params
===============================

.. py:module:: paidiverpy.models.custom_params

.. autoapi-nested-parse::

   Custom parameters dataclasses.

   This module contains the dataclasses for the parameters used in the custom_params module.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.models.custom_params.CustomParams


Module Contents
---------------

.. py:class:: CustomParams(/, **data: Any)

   Bases: :py:obj:`paidiverpy.utils.base_model.BaseModel`


   
   Parameters for the custom_params module with support for arbitrary fields.
















   ..
       !! processed by numpydoc !!

   .. py:attribute:: model_config
      :type:  ClassVar[dict[str, object]]

      
      Configuration for the model, should be a dictionary conforming to [`ConfigDict`][pydantic.config.ConfigDict].
















      ..
          !! processed by numpydoc !!


